Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1349)

Unified Diff: Source/core/layout/compositing/CompositedDeprecatedPaintLayerMapping.h

Issue 1162383003: C++11: Replace 0 with nullptr where applicable in layout code. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Add one more file. Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/layout/compositing/CompositedDeprecatedPaintLayerMapping.h
diff --git a/Source/core/layout/compositing/CompositedDeprecatedPaintLayerMapping.h b/Source/core/layout/compositing/CompositedDeprecatedPaintLayerMapping.h
index 61c4d99de013552e599e3fb7c7fb08108f4784a7..2f6f31d48ec47153e6a730791bc788789f5af95e 100644
--- a/Source/core/layout/compositing/CompositedDeprecatedPaintLayerMapping.h
+++ b/Source/core/layout/compositing/CompositedDeprecatedPaintLayerMapping.h
@@ -50,7 +50,7 @@ struct GraphicsLayerPaintInfo {
IntSize offsetFromLayoutObject;
bool offsetFromLayoutObjectSet;
- GraphicsLayerPaintInfo() : paintLayer(0), offsetFromLayoutObjectSet(false) { }
+ GraphicsLayerPaintInfo() : paintLayer(nullptr), offsetFromLayoutObjectSet(false) { }
};
enum GraphicsLayerUpdateScope {
@@ -189,7 +189,7 @@ public:
return m_squashingLayerOffsetFromTransformedAncestor;
}
// If there is a squashed layer painting into this CLM that is an ancestor of the given LayoutObject, return it. Otherwise return 0.
const GraphicsLayerPaintInfo* containingSquashedLayer(const LayoutObject*, unsigned maxSquashedLayerIndex);
void updateScrollingBlockSelection();
« no previous file with comments | « Source/core/layout/TextRunConstructor.cpp ('k') | Source/core/layout/compositing/CompositedDeprecatedPaintLayerMapping.cpp » ('j') | no next file with comments »
@@ -189,7 +189,7 @@ public:
return m_squashingLayerOffsetFromTransformedAncestor;
}
- // If there is a squashed layer painting into this CLM that is an ancestor of the given LayoutObject, return it. Otherwise return 0.
+ // If there is a squashed layer painting into this CLM that is an ancestor of the given LayoutObject, return it. Otherwise return nullptr.
const GraphicsLayerPaintInfo* containingSquashedLayer(const LayoutObject*, unsigned maxSquashedLayerIndex);
void updateScrollingBlockSelection();

Powered by Google App Engine
This is Rietveld 408576698